@@ -1,4 +1,4 @@
-__version__ = "0.2.5"
+__version__ = "0.4.3"
 __url__ = "https://github.com/amisadmin/fastapi_amis_admin"
 
 import gettext
@@ -14,6 +14,11 @@ i18n.load_translations(
             domain="messages",
             localedir=os.path.join(BASE_DIR, "locale"),
             languages=["zh_CN"],
-        )
+        ),
+        "de_DE": gettext.translation(
+            domain="messages",
+            localedir=os.path.join(BASE_DIR, "locale"),
+            languages=["de_DE"],
+        ),
     }
 )
