@@ -5,11 +5,13 @@ from typing import (
     Any,
     Callable,
     Dict,
+    Generic,
     Iterable,
     Iterator,
     List,
     NewType,
     Optional,
+    Tuple,
     Type,
     TypeVar,
     Union,
@@ -24,11 +26,12 @@ from sqlalchemy.orm import InstrumentedAttribute, RelationshipProperty
 from sqlalchemy.sql.elements import Label
 from sqlalchemy.util import md5_hex
 from sqlalchemy_database import AsyncDatabase, Database
-from sqlmodel import SQLModel, select
+from sqlmodel import SQLModel
 from starlette import status
 from starlette.middleware.base import BaseHTTPMiddleware
 from starlette.responses import HTMLResponse, JSONResponse, Response
 from starlette.templating import Jinja2Templates
+from typing_extensions import Literal
 
 import fastapi_amis_admin
 from fastapi_amis_admin.admin.handlers import register_exception_handlers
@@ -66,7 +69,13 @@ from fastapi_amis_admin.amis.types import (
     BaseAmisModel,
     SchemaNode,
 )
-from fastapi_amis_admin.crud import RouterMixin, SQLModelCrud, SQLModelSelector
+from fastapi_amis_admin.crud import RouterMixin, SQLModelCrud
+from fastapi_amis_admin.crud.base import (
+    SchemaCreateT,
+    SchemaFilterT,
+    SchemaModelT,
+    SchemaUpdateT,
+)
 from fastapi_amis_admin.crud.parser import (
     SQLModelFieldParser,
     SQLModelListField,
@@ -83,11 +92,6 @@ from fastapi_amis_admin.crud.utils import (
 from fastapi_amis_admin.utils.functools import cached_property
 from fastapi_amis_admin.utils.translation import i18n as _
 
-try:
-    from typing import Literal
-except ImportError:
-    from typing_extensions import Literal
-
 _BaseAdminT = TypeVar("_BaseAdminT", bound="BaseAdmin")
 _PageSchemaAdminT = TypeVar("_PageSchemaAdminT", bound="PageSchemaAdmin")
 _BaseModel = NewType("_BaseModel", BaseModel)
@@ -112,7 +116,7 @@ class LinkModelForm:
         self.item_col = item_col
         assert self.item_col is not None, "item_col is None"
         assert self.link_col is not None, "link_col is None"
-        self.path = f"/{self.display_admin.model.__name__.lower()}"
+        self.path = f"/{self.display_admin.model.__name__}"
 
     @classmethod
     def bind_model_admin(cls, pk_admin: "BaseModelAdmin", insfield: InstrumentedAttribute) -> Optional["LinkModelForm"]:
@@ -125,7 +129,7 @@ class LinkModelForm:
         link_key = None
         item_key = None
         for key in table.foreign_keys:
-            if key.column.table != pk_admin.model.__table__:  # 获取关联第三方表
+            if key.column.table != pk_admin.model.__table__:  # Get the associated third-party table
                 admin = pk_admin.app.site.get_model_admin(key.column.table.name)
                 link_key = key
             else:
@@ -319,14 +323,15 @@ class LinkModelForm:
 
 
 class BaseModelAdmin(SQLModelCrud):
-    list_display: List[Union[SQLModelListField, TableColumn]] = []  # 需要显示的字段
-    list_filter: List[Union[SQLModelListField, FormItem]] = []  # 查询可过滤的字段
-    list_per_page: int = 10  # 每页数据量
-    link_model_fields: List[InstrumentedAttribute] = []  # 内联字段
+    list_display: List[Union[SQLModelListField, TableColumn]] = []  # Fields to be displayed
+    list_filter: List[Union[SQLModelListField, FormItem]] = []  # Query filterable fields
+    list_per_page: int = 10  # Amount of data per page
+    link_model_fields: List[InstrumentedAttribute] = []  # inline field
     link_model_forms: List[LinkModelForm] = []
-    bulk_update_fields: List[Union[SQLModelListField, FormItem]] = []  # 批量编辑字段
-    enable_bulk_create: bool = False  # 是否启用批量创建
-    search_fields: List[SQLModelListField] = []  # 模糊搜索字段
+    bulk_update_fields: List[Union[SQLModelListField, FormItem]] = []  # Bulk edit fields
+    enable_bulk_create: bool = False  # whether to enable batch creation
+    search_fields: List[SQLModelListField] = []  # fuzzy search fields
+    page_schema: Union[PageSchema, str] = PageSchema()
 
     def __init__(self, app: "AdminApp"):
         assert self.model, "model is None"
@@ -380,10 +385,10 @@ class BaseModelAdmin(SQLModelCrud):
                 columns.append(field)
             elif isinstance(field, type) and issubclass(field, SQLModel):
                 ins_list = self.parser.get_sqlmodel_insfield(field)
-                modelfields = [self.parser.get_modelfield(ins, deepcopy=True) for ins in ins_list]
+                modelfields = [self.parser.get_modelfield(ins) for ins in ins_list]
                 columns.extend([await self.get_list_column(request, modelfield) for modelfield in modelfields])
             else:
-                modelfield = self.parser.get_modelfield(field, deepcopy=True)
+                modelfield = self.parser.get_modelfield(field)
                 if modelfield:
                     columns.append(await self.get_list_column(request, modelfield))
         for link_form in self.link_model_forms:
@@ -406,9 +411,12 @@ class BaseModelAdmin(SQLModelCrud):
             if alias:
                 data[alias] = f"[~]${alias}"
         for field in await self.get_list_filter(request):
-            modelfield = self.parser.get_modelfield(field, deepcopy=True)
-            if modelfield and issubclass(modelfield.type_, (datetime.datetime, datetime.date, datetime.time)):
-                data[modelfield.alias] = f"[-]${modelfield.alias}"
+            if isinstance(field, FormItem):
+                data[field.name] = f"${field.name}"
+            else:
+                modelfield = self.parser.get_modelfield(field)
+                if modelfield and issubclass(modelfield.type_, (datetime.datetime, datetime.date, datetime.time)):
+                    data[modelfield.alias] = f"[-]${modelfield.alias}"
         return AmisAPI(
             method="POST",
             url=f"{self.router_path}/list?" + "page=${page}&perPage=${perPage}&orderBy=${orderBy}&orderDir=${orderDir}",
@@ -453,7 +461,7 @@ class BaseModelAdmin(SQLModelCrud):
             ],
             columns=await self.get_list_columns(request),
             primaryField=self.pk_name,
-            quickSaveItemApi=f"put:{self.router_path}/item/" + "${id}",
+            quickSaveItemApi=f"put:{self.router_path}/item/${self.pk_name}",
         )
         if self.link_model_forms:
             table.footable = True
@@ -541,7 +549,7 @@ class BaseModelAdmin(SQLModelCrud):
             )
         columns, keys = [], {}
         for field in fields:
-            column = await self.get_list_column(request, self.parser.get_modelfield(field, deepcopy=True))
+            column = await self.get_list_column(request, self.parser.get_modelfield(field))
             keys[column.name] = "${" + column.label + "}"
             column.name = column.label
             columns.append(column)
@@ -567,9 +575,12 @@ class BaseModelAdmin(SQLModelCrud):
         )
 
     async def get_update_form(self, request: Request, bulk: bool = False) -> Form:
+        extra = {}
         if not bulk:
             api = f"put:{self.router_path}/item/${self.pk_name}"
             fields = self.schema_update.__fields__.values()
+            if self.schema_read:
+                extra["initApi"] = f"get:{self.router_path}/item/${self.pk_name}"
         else:
             api = f"put:{self.router_path}/item/" + "${ids|raw}"
             fields = self.bulk_update_fields
@@ -579,6 +590,30 @@ class BaseModelAdmin(SQLModelCrud):
             body=await self._conv_modelfields_to_formitems(request, fields, CrudEnum.update),
             submitText=None,
             trimValues=True,
+            **extra,
+        )
+
+    async def get_read_form(self, request: Request) -> Form:
+        return Form(
+            initApi=f"get:{self.router_path}/item/${self.pk_name}",
+            name=CrudEnum.read,
+            body=await self._conv_modelfields_to_formitems(request, self.schema_read.__fields__.values(), CrudEnum.read),
+            submitText=None,
+            static=True,
+        )
+
+    async def get_read_action(self, request: Request) -> Optional[Action]:
+        if not self.schema_read:
+            return None
+        return ActionType.Dialog(
+            icon="fa fa-eye",
+            tooltip=_("View"),
+            level=LevelEnum.primary,
+            dialog=Dialog(
+                title=_("View") + " - " + _(self.page_schema.label),
+                size=SizeEnum.lg,
+                body=await self.get_read_form(request),
+            ),
         )
 
     async def get_create_action(self, request: Request, bulk: bool = False) -> Optional[Action]:
@@ -609,7 +644,7 @@ class BaseModelAdmin(SQLModelCrud):
     async def get_update_action(self, request: Request, bulk: bool = False) -> Optional[Action]:
         if not await self.has_update_permission(request, None, None):
             return None
-        # 开启批量编辑
+        # Turn on batch editing
         if not bulk:
             return ActionType.Dialog(
                 icon="fa fa-pencil",
@@ -662,6 +697,7 @@ class BaseModelAdmin(SQLModelCrud):
 
     async def get_actions_on_item(self, request: Request) -> List[Action]:
         actions = [
+            await self.get_read_action(request),
             await self.get_update_action(request, bulk=False),
             await self.get_delete_action(request, bulk=False),
         ]
@@ -685,7 +721,7 @@ class BaseModelAdmin(SQLModelCrud):
             if isinstance(field, FormItem):
                 items.append(field)
             else:
-                field = self.parser.get_modelfield(field, deepcopy=True)
+                field = self.parser.get_modelfield(field)
                 if field:
                     item = await self.get_form_item(request, field, action)
                     if item:
@@ -712,7 +748,7 @@ class BaseAdmin:
 
 
 class PageSchemaAdmin(BaseAdmin):
-    group_schema: Union[PageSchema, str] = None
+    group_schema: Union[PageSchema, str] = None  # todo Deprecated
     page_schema: Union[PageSchema, str] = PageSchema()
 
     def __init__(self, app: "AdminApp"):
@@ -790,7 +826,7 @@ class RouterAdmin(BaseAdmin, RouterMixin):
 
 
 class PageAdmin(PageSchemaAdmin, RouterAdmin):
-    """Amis页面管理"""
+    """Amis page management"""
 
     page: Page = None
     page_path: Optional[str] = None
@@ -802,7 +838,7 @@ class PageAdmin(PageSchemaAdmin, RouterAdmin):
     def __init__(self, app: "AdminApp"):
         RouterAdmin.__init__(self, app)
         if self.page_path is None:
-            self.page_path = f"/{self.__class__.__module__}/{self.__class__.__name__.lower()}"
+            self.page_path = f"/{self.__class__.__module__}/{self.__class__.__name__}"
         PageSchemaAdmin.__init__(self, app)
 
     async def page_permission_depend(self, request: Request) -> bool:
@@ -813,7 +849,7 @@ class PageAdmin(PageSchemaAdmin, RouterAdmin):
             status_code=status.HTTP_307_TEMPORARY_REDIRECT,
             detail="No page permissions",
             headers={
-                "location": f"{self.app.site.router_path}/auth/form/login?redirect={request.url}",
+                "location": f"{self.app.site.router_path}/auth/form/login?redirect={request.url.path}",
             },
         )
 
@@ -883,7 +919,7 @@ class PageAdmin(PageSchemaAdmin, RouterAdmin):
 
 
 class TemplateAdmin(PageAdmin):
-    """Jinja2渲染模板管理"""
+    """Jinja2 render template management"""
 
     page: Dict[str, Any] = {}
     page_parser_mode = "html"
@@ -903,8 +939,8 @@ class TemplateAdmin(PageAdmin):
         return {}
 
 
-class BaseFormAdmin(PageAdmin):
-    schema: Type[BaseModel] = None
+class BaseFormAdmin(PageAdmin, Generic[SchemaUpdateT]):
+    schema: Type[SchemaUpdateT] = None
     schema_init_out: Type[Any] = Any
     schema_submit_out: Type[Any] = Any
     form: Form = None
@@ -964,7 +1000,7 @@ class BaseFormAdmin(PageAdmin):
 
 
 class FormAdmin(BaseFormAdmin):
-    """表单管理"""
+    """Form management"""
 
     @property
     def route_submit(self):
@@ -975,7 +1011,7 @@ class FormAdmin(BaseFormAdmin):
 
         return route
 
-    async def handle(self, request: Request, data: BaseModel, **kwargs) -> BaseApiOut[Any]:
+    async def handle(self, request: Request, data: SchemaUpdateT, **kwargs) -> BaseApiOut[Any]:
         raise NotImplementedError
 
     async def get_init_data(self, request: Request, **kwargs) -> BaseApiOut[Any]:
@@ -989,16 +1025,8 @@ class FormAdmin(BaseFormAdmin):
         return route
 
 
-class ModelFormAdmin(FormAdmin, SQLModelSelector):
-    """todo Read and update a model resource"""
-
-    def __init__(self, app: "AdminApp"):
-        FormAdmin.__init__(self, app)
-        SQLModelSelector.__init__(self)
-
-
 class ModelAdmin(BaseModelAdmin, PageAdmin):
-    """模型管理"""
+    """Model management"""
 
     page_path: str = ""
     bind_model: bool = True
@@ -1010,8 +1038,8 @@ class ModelAdmin(BaseModelAdmin, PageAdmin):
     @property
     def router_prefix(self):
         if issubclass(self.__class__.__base__, ModelAdmin):
-            return f"/{self.__class__.__name__.lower()}"
-        return f"/{self.model.__name__.lower()}"
+            return f"/{self.__class__.__name__}"
+        return f"/{self.model.__name__}"
 
     def register_router(self):
         for form in self.link_model_forms:
@@ -1029,12 +1057,12 @@ class ModelAdmin(BaseModelAdmin, PageAdmin):
         self,
         request: Request,
         paginator: Paginator,
-        filters: BaseModel = None,  # type self.schema_filter
+        filters: SchemaFilterT = None,
         **kwargs,
     ) -> bool:
         return await self.has_page_permission(request)
 
-    async def has_create_permission(self, request: Request, data: BaseModel, **kwargs) -> bool:  # type self.schema_create
+    async def has_create_permission(self, request: Request, data: SchemaCreateT, **kwargs) -> bool:  # type self.schema_create
         return await self.has_page_permission(request)
 
     async def has_read_permission(self, request: Request, item_id: List[str], **kwargs) -> bool:
@@ -1044,7 +1072,7 @@ class ModelAdmin(BaseModelAdmin, PageAdmin):
         self,
         request: Request,
         item_id: List[str],
-        data: BaseModel,  # type self.schema_update
+        data: SchemaUpdateT,
         **kwargs,
     ) -> bool:
         return await self.has_page_permission(request)
@@ -1073,9 +1101,9 @@ class BaseModelAction:
         self.admin = admin
         assert self.admin, "admin is None"
 
-    async def fetch_item_scalars(self, item_id: List[str]) -> List[BaseModel]:
-        stmt = select(self.admin.model).where(self.admin.pk.in_(item_id))
-        return await self.admin.db.async_scalars_all(stmt)
+    async def fetch_item_scalars(self, item_id: List[str]) -> List[SchemaModelT]:
+        # noinspection PyProtectedMember
+        return await self.admin.db.async_run_sync(self.admin._fetch_item_scalars, item_id)
 
     def register_router(self):
         raise NotImplementedError
@@ -1102,7 +1130,6 @@ class FormAction(FormAdmin, BaseFormAction):
 
 
 class ModelAction(BaseFormAdmin, BaseModelAction):
-    schema: Type[BaseModel] = None
     action: ActionType.Dialog = None
 
     def __init__(self, admin: "ModelAdmin"):
@@ -1126,7 +1153,7 @@ class ModelAction(BaseFormAdmin, BaseModelAction):
         )
         return action
 
-    async def handle(self, request: Request, item_id: List[str], data: Optional[BaseModel], **kwargs) -> BaseApiOut[Any]:
+    async def handle(self, request: Request, item_id: List[str], data: Optional[SchemaUpdateT], **kwargs) -> BaseApiOut[Any]:
         return BaseApiOut(data=data)
 
     @property
@@ -1176,13 +1203,19 @@ class AdminGroup(PageSchemaAdmin):
             group.append_child(child, group_schema=None)
             self._children.append(group)
 
+    def remove_child(self, unique_id: str) -> None:
+        self._children = [admin for admin in self._children if admin.unique_id != unique_id]
+        for admin in self._children:
+            if isinstance(admin, AdminGroup):
+                admin.remove_child(unique_id)
+
     async def get_page_schema_children(self, request: Request) -> List[PageSchema]:
         page_schema_list = []
         for child in self._children:
             if not child.page_schema or not await child.has_page_permission(request):
                 continue
             if (isinstance(child, AdminGroup) and not isinstance(child, AdminApp)) or (
-                isinstance(child, AdminApp) and child.tabs_mode is None
+                isinstance(child, AdminApp) and child.page_schema.tabsMode is None
             ):
                 sub_children = await child.get_page_schema_children(request)
                 if sub_children:
@@ -1195,26 +1228,26 @@ class AdminGroup(PageSchemaAdmin):
             page_schema_list.sort(key=lambda p: p.sort or 0, reverse=True)
         return page_schema_list
 
-    def get_page_schema_child(self, unique_id: str) -> Optional[_PageSchemaAdminT]:
+    def get_page_schema_child(self, unique_id: str) -> Union[Tuple[_PageSchemaAdminT, "AdminGroup"], Tuple[None, None]]:
         for child in self._children:
             if child.unique_id == unique_id:
-                return child
+                return child, self
             if isinstance(child, AdminGroup):
-                child = child.get_page_schema_child(unique_id)
+                child, parent = child.get_page_schema_child(unique_id)
                 if child:
-                    return child
-        return None
+                    return child, parent
+        return None, None
 
     def __iter__(self) -> Iterator[_PageSchemaAdminT]:
         return self._children.__iter__()
 
 
 class AdminApp(PageAdmin, AdminGroup):
-    """管理应用"""
+    """Manage applications"""
 
     engine: SqlalchemyDatabase = None
     page_path = "/"
-    tabs_mode: TabsModeEnum = None
+    tabs_mode: TabsModeEnum = None  # Deprecated. Use the tabsMode attribute in the page_schema.
 
     def __init__(self, app: "AdminApp"):
         PageAdmin.__init__(self, app)
@@ -1226,7 +1259,7 @@ class AdminApp(PageAdmin, AdminGroup):
 
     @property
     def router_prefix(self):
-        return f"/{self.__class__.__name__.lower()}"
+        return f"/{self.__class__.__name__}"
 
     def get_admin_or_create(self, admin_cls: Type[_BaseAdminT], register: bool = True) -> Optional[_BaseAdminT]:
         if admin_cls not in self._registered and (not register or self.__register_lock):
@@ -1248,7 +1281,7 @@ class AdminApp(PageAdmin, AdminGroup):
 
     def _register_admin_router_all(self):
         for admin in self._registered.values():
-            if isinstance(admin, RouterAdmin):  # 注册路由
+            if isinstance(admin, RouterAdmin):  # register route
                 admin.register_router()
                 self.router.include_router(admin.router)
 
@@ -1281,12 +1314,14 @@ class AdminApp(PageAdmin, AdminGroup):
         [self._registered.pop(cls) for cls in admin_cls if cls]
 
     def get_page_schema(self) -> Optional[PageSchema]:
-        if super().get_page_schema() and self.tabs_mode is None:
-            self.page_schema.schemaApi = None
+        if super().get_page_schema():
+            self.page_schema.tabsMode = self.tabs_mode
+            if self.page_schema.tabsMode is None:
+                self.page_schema.schemaApi = None
         return self.page_schema
 
     async def get_page(self, request: Request) -> Union[Page, App]:
-        if self.tabs_mode is None:
+        if self.page_schema.tabsMode is None:
             return await self._get_page_as_app(request)
         return await self._get_page_as_tabs(request)
 
@@ -1317,7 +1352,7 @@ class AdminApp(PageAdmin, AdminGroup):
     async def _get_page_as_tabs(self, request: Request) -> Page:
         page = await super(AdminApp, self).get_page(request)
         children = await self.get_page_schema_children(request)
-        page.body = PageSchema(children=children).as_tabs_item(tabs_extra=dict(tabsMode=self.tabs_mode, mountOnEnter=True)).tab
+        page.body = PageSchema(children=children, tabsMode=self.page_schema.tabsMode).as_tabs_item().tab
         return page
 
 
@@ -1328,10 +1363,11 @@ class BaseAdminSite(AdminApp):
         fastapi: FastAPI = None,
         engine: SqlalchemyDatabase = None,
     ):
+        self.application = None
         try:
             from fastapi_user_auth.auth import Auth
 
-            self.auth: Auth = None
+            self.auth: Auth = None  # type: ignore
         except ImportError:
             pass
         self.settings = settings
@@ -1358,6 +1394,7 @@ class BaseAdminSite(AdminApp):
         """mount app to fastapi, the path is: site.settings.root_path.
         once mount, the site will create all registered admin instance and register router.
         """
+        self.application = fastapi
         self.register_router()
         fastapi.mount(self.settings.root_path, self.fastapi, name=name)
         fastapi.add_middleware(BaseHTTPMiddleware, dispatch=self.db.asgi_dispatch)
