@@ -8,7 +8,7 @@ from fastapi_amis_admin.amis import API
 
 
 class Settings(BaseSettings):
-    """项目配置"""
+    """Project configuration"""
 
     host: str = "127.0.0.1"
     port: int = 8000
@@ -22,10 +22,10 @@ class Settings(BaseSettings):
     database_url: str = Field("", env="DATABASE_URL")
     language: Union[Literal["zh_CN", "en_US", "de_DE"], str] = ""
     amis_cdn: str = "https://unpkg.com"
-    amis_pkg: str = "amis@2.3.1"
+    amis_pkg: str = "amis@2.6.0"
     amis_theme: Literal["cxd", "antd", "dark", "ang"] = "cxd"
-    amis_image_receiver: API = None  # 图片上传接口
-    amis_file_receiver: API = None  # 文件上传接口
+    amis_image_receiver: API = None  # Image upload interface
+    amis_file_receiver: API = None  # File upload interface
     logger: Union[logging.Logger, Any] = logging.getLogger("fastapi_amis_admin")
 
     @validator("amis_cdn", "root_path", "site_url", pre=True)
@@ -43,4 +43,4 @@ class Settings(BaseSettings):
 
     @validator("amis_image_receiver", "amis_file_receiver", pre=True)
     def valid_receiver(cls, v, values):
-        return v if v else f"post:{values.get('root_path', '')}/file/upload"
+        return v or f"post:{values.get('root_path', '')}/file/upload"
